# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: chalk/server/v1/prompt.proto
# Protobuf Python Version: 4.25.3
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from chalk._gen.chalk.auth.v1 import permissions_pb2 as chalk_dot_auth_dot_v1_dot_permissions__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1c\x63halk/server/v1/prompt.proto\x12\x0f\x63halk.server.v1\x1a\x1f\x63halk/auth/v1/permissions.proto\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto">\n\x0ePromptTemplate\x12\x12\n\x04type\x18\x01 \x01(\tR\x04type\x12\x18\n\x07message\x18\x02 \x01(\tR\x07message"\xbb\x02\n\x0eProviderConfig\x12\x1a\n\x08provider\x18\x01 \x01(\tR\x08provider\x12\x1d\n\nmodel_name\x18\x02 \x01(\tR\tmodelName\x12O\n\nparameters\x18\x03 \x03(\x0b\x32/.chalk.server.v1.ProviderConfig.ParametersEntryR\nparameters\x12\x30\n\x11structured_output\x18\x04 \x01(\tH\x00R\x10structuredOutput\x88\x01\x01\x1aU\n\x0fParametersEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12,\n\x05value\x18\x02 \x01(\x0b\x32\x16.google.protobuf.ValueR\x05value:\x02\x38\x01\x42\x14\n\x12_structured_output"\xf7\x04\n\rPromptVariant\x12\x0e\n\x02id\x18\x01 \x01(\x03R\x02id\x12%\n\x0e\x65nvironment_id\x18\x02 \x01(\tR\renvironmentId\x12#\n\rdeployment_id\x18\x03 \x01(\tR\x0c\x64\x65ploymentId\x12+\n\x0fnamed_prompt_id\x18\x04 \x01(\tH\x00R\rnamedPromptId\x88\x01\x01\x12/\n\x11\x65valuation_run_id\x18\x05 \x01(\tH\x01R\x0f\x65valuationRunId\x88\x01\x01\x12$\n\x0b\x63ommit_hash\x18\x06 \x01(\tH\x02R\ncommitHash\x88\x01\x01\x12=\n\ttemplates\x18\x07 \x03(\x0b\x32\x1f.chalk.server.v1.PromptTemplateR\ttemplates\x12\x1c\n\tvariables\x18\x08 \x03(\tR\tvariables\x12H\n\x0fprovider_config\x18\t \x01(\x0b\x32\x1f.chalk.server.v1.ProviderConfigR\x0eproviderConfig\x12&\n\x0cvariant_hash\x18\n \x01(\tH\x03R\x0bvariantHash\x88\x01\x01\x12"\n\ncreated_by\x18\x0b \x01(\tH\x04R\tcreatedBy\x88\x01\x01\x12\x39\n\ncreated_at\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAtB\x12\n\x10_named_prompt_idB\x14\n\x12_evaluation_run_idB\x0e\n\x0c_commit_hashB\x0f\n\r_variant_hashB\r\n\x0b_created_by"\xb5\x04\n\x0bNamedPrompt\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12%\n\x0e\x65nvironment_id\x18\x02 \x01(\tR\renvironmentId\x12#\n\rdeployment_id\x18\x03 \x01(\tR\x0c\x64\x65ploymentId\x12\x12\n\x04name\x18\x04 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x05 \x01(\tR\x0b\x64\x65scription\x12\x12\n\x04tags\x18\x06 \x03(\tR\x04tags\x12"\n\ncreated_by\x18\x07 \x01(\tH\x00R\tcreatedBy\x88\x01\x01\x12\x39\n\ncreated_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12>\n\nupdated_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x01R\tupdatedAt\x88\x01\x01\x12@\n\x0b\x61rchived_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x02R\narchivedAt\x88\x01\x01\x12W\n\x15latest_prompt_variant\x18\x0b \x01(\x0b\x32\x1e.chalk.server.v1.PromptVariantH\x03R\x13latestPromptVariant\x88\x01\x01\x42\r\n\x0b_created_byB\r\n\x0b_updated_atB\x0e\n\x0c_archived_atB\x18\n\x16_latest_prompt_variant"\xfa\x08\n\x13PromptEvaluationRun\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12%\n\x0e\x65nvironment_id\x18\x02 \x01(\tR\renvironmentId\x12#\n\rdeployment_id\x18\x03 \x01(\tR\x0c\x64\x65ploymentId\x12\x1f\n\x0b\x62ranch_name\x18\x04 \x01(\tR\nbranchName\x12\x1d\n\ndataset_id\x18\x05 \x01(\tR\tdatasetId\x12.\n\x13\x64\x61taset_revision_id\x18\x06 \x01(\tR\x11\x64\x61tasetRevisionId\x12.\n\x10reference_output\x18\x07 \x01(\tH\x00R\x0freferenceOutput\x88\x01\x01\x12\x1e\n\nevaluators\x18\x08 \x03(\tR\nevaluators\x12*\n\x11offline_query_ids\x18\t \x03(\tR\x0fofflineQueryIds\x12\x37\n\x18related_named_prompt_ids\x18\n \x03(\tR\x15relatedNamedPromptIds\x12\x34\n\x16related_evaluation_ids\x18\x0b \x03(\tR\x14relatedEvaluationIds\x12g\n\x11\x61ggregate_metrics\x18\x0c \x03(\x0b\x32:.chalk.server.v1.PromptEvaluationRun.AggregateMetricsEntryR\x10\x61ggregateMetrics\x12O\n\tmeta_data\x18\r \x03(\x0b\x32\x32.chalk.server.v1.PromptEvaluationRun.MetaDataEntryR\x08metaData\x12"\n\ncreated_by\x18\x0e \x01(\tH\x01R\tcreatedBy\x88\x01\x01\x12\x39\n\ncreated_at\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12&\n\x0c\x64\x61taset_name\x18\x10 \x01(\tH\x02R\x0b\x64\x61tasetName\x88\x01\x01\x12;\n\x1arelated_named_prompt_names\x18\x11 \x03(\tR\x17relatedNamedPromptNames\x12G\n\x0fprompt_variants\x18\x12 \x03(\x0b\x32\x1e.chalk.server.v1.PromptVariantR\x0epromptVariants\x1a[\n\x15\x41ggregateMetricsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12,\n\x05value\x18\x02 \x01(\x0b\x32\x16.google.protobuf.ValueR\x05value:\x02\x38\x01\x1aS\n\rMetaDataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12,\n\x05value\x18\x02 \x01(\x0b\x32\x16.google.protobuf.ValueR\x05value:\x02\x38\x01\x42\x13\n\x11_reference_outputB\r\n\x0b_created_byB\x0f\n\r_dataset_name"f\n\x17ListNamedPromptsRequest\x12\x1b\n\x06\x63ursor\x18\x01 \x01(\tH\x00R\x06\x63ursor\x88\x01\x01\x12\x19\n\x05limit\x18\x02 \x01(\x05H\x01R\x05limit\x88\x01\x01\x42\t\n\x07_cursorB\x08\n\x06_limit"\x93\x01\n\x18ListNamedPromptsResponse\x12\x41\n\rnamed_prompts\x18\x01 \x03(\x0b\x32\x1c.chalk.server.v1.NamedPromptR\x0cnamedPrompts\x12$\n\x0bnext_cursor\x18\x02 \x01(\tH\x00R\nnextCursor\x88\x01\x01\x42\x0e\n\x0c_next_cursor"?\n\x15GetNamedPromptRequest\x12&\n\x0fnamed_prompt_id\x18\x01 \x01(\tR\rnamedPromptId"o\n\x16GetNamedPromptResponse\x12\x44\n\x0cnamed_prompt\x18\x01 \x01(\x0b\x32\x1c.chalk.server.v1.NamedPromptH\x00R\x0bnamedPrompt\x88\x01\x01\x42\x0f\n\r_named_prompt"\xa1\x01\n\x16PromptVariantOperation\x12=\n\ttemplates\x18\x01 \x03(\x0b\x32\x1f.chalk.server.v1.PromptTemplateR\ttemplates\x12H\n\x0fprovider_config\x18\x02 \x01(\x0b\x32\x1f.chalk.server.v1.ProviderConfigR\x0eproviderConfig"\xb4\x01\n\x18\x43reateNamedPromptRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\x12\x12\n\x04tags\x18\x03 \x03(\tR\x04tags\x12N\n\x0eprompt_variant\x18\x04 \x01(\x0b\x32\'.chalk.server.v1.PromptVariantOperationR\rpromptVariant"\\\n\x19\x43reateNamedPromptResponse\x12?\n\x0cnamed_prompt\x18\x01 \x01(\x0b\x32\x1c.chalk.server.v1.NamedPromptR\x0bnamedPrompt"\xc3\x02\n\x1aUpdateNamedPromptOperation\x12\x17\n\x04name\x18\x01 \x01(\tH\x00R\x04name\x88\x01\x01\x12%\n\x0b\x64\x65scription\x18\x02 \x01(\tH\x01R\x0b\x64\x65scription\x88\x01\x01\x12\x12\n\x04tags\x18\x03 \x03(\tR\x04tags\x12S\n\x0eprompt_variant\x18\x04 \x01(\x0b\x32\'.chalk.server.v1.PromptVariantOperationH\x02R\rpromptVariant\x88\x01\x01\x12@\n\x0b\x61rchived_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x03R\narchivedAt\x88\x01\x01\x42\x07\n\x05_nameB\x0e\n\x0c_descriptionB\x11\n\x0f_prompt_variantB\x0e\n\x0c_archived_at"\xc4\x01\n\x18UpdateNamedPromptRequest\x12&\n\x0fnamed_prompt_id\x18\x01 \x01(\tR\rnamedPromptId\x12\x43\n\x06update\x18\x02 \x01(\x0b\x32+.chalk.server.v1.UpdateNamedPromptOperationR\x06update\x12;\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskR\nupdateMask"\\\n\x19UpdateNamedPromptResponse\x12?\n\x0cnamed_prompt\x18\x01 \x01(\x0b\x32\x1c.chalk.server.v1.NamedPromptR\x0bnamedPrompt"\xf0\x01\n\x19ListPromptVariantsRequest\x12+\n\x0fnamed_prompt_id\x18\x01 \x01(\tH\x00R\rnamedPromptId\x88\x01\x01\x12/\n\x11\x65valuation_run_id\x18\x02 \x01(\tH\x01R\x0f\x65valuationRunId\x88\x01\x01\x12\x1b\n\x06\x63ursor\x18\x03 \x01(\tH\x02R\x06\x63ursor\x88\x01\x01\x12\x19\n\x05limit\x18\x04 \x01(\x05H\x03R\x05limit\x88\x01\x01\x42\x12\n\x10_named_prompt_idB\x14\n\x12_evaluation_run_idB\t\n\x07_cursorB\x08\n\x06_limit"\x9b\x01\n\x1aListPromptVariantsResponse\x12G\n\x0fprompt_variants\x18\x01 \x03(\x0b\x32\x1e.chalk.server.v1.PromptVariantR\x0epromptVariants\x12$\n\x0bnext_cursor\x18\x02 \x01(\tH\x00R\nnextCursor\x88\x01\x01\x42\x0e\n\x0c_next_cursor"\xaf\x01\n\x1fListPromptEvaluationRunsRequest\x12\x1b\n\x06\x63ursor\x18\x01 \x01(\tH\x00R\x06\x63ursor\x88\x01\x01\x12\x19\n\x05limit\x18\x02 \x01(\x05H\x01R\x05limit\x88\x01\x01\x12+\n\x0fnamed_prompt_id\x18\x03 \x01(\tH\x02R\rnamedPromptId\x88\x01\x01\x42\t\n\x07_cursorB\x08\n\x06_limitB\x12\n\x10_named_prompt_id"\xa7\x01\n ListPromptEvaluationRunsResponse\x12M\n\x0f\x65valuation_runs\x18\x01 \x03(\x0b\x32$.chalk.server.v1.PromptEvaluationRunR\x0e\x65valuationRuns\x12$\n\x0bnext_cursor\x18\x02 \x01(\tH\x00R\nnextCursor\x88\x01\x01\x42\x0e\n\x0c_next_cursor"\xdb\x02\n\x1dGetPromptEvaluationRunRequest\x12,\n\x11\x65valuation_run_id\x18\x01 \x01(\tH\x00R\x0f\x65valuationRunId\x12h\n\x0fprefill_options\x18\x02 \x01(\x0b\x32=.chalk.server.v1.GetPromptEvaluationRunRequest.PrefillOptionsH\x00R\x0eprefillOptions\x1a\x98\x01\n\x0ePrefillOptions\x12+\n\x0fnamed_prompt_id\x18\x01 \x01(\tH\x00R\rnamedPromptId\x88\x01\x01\x12/\n\x11\x65valuation_run_id\x18\x02 \x01(\tH\x01R\x0f\x65valuationRunId\x88\x01\x01\x42\x12\n\x10_named_prompt_idB\x14\n\x12_evaluation_run_idB\x07\n\x05query"\x85\x01\n\x1eGetPromptEvaluationRunResponse\x12P\n\x0e\x65valuation_run\x18\x01 \x01(\x0b\x32$.chalk.server.v1.PromptEvaluationRunH\x00R\revaluationRun\x88\x01\x01\x42\x11\n\x0f_evaluation_run"\xeb\x04\n CreatePromptEvaluationRunRequest\x12\x1f\n\x0b\x62ranch_name\x18\x01 \x01(\tR\nbranchName\x12\x1d\n\ndataset_id\x18\x02 \x01(\tR\tdatasetId\x12.\n\x13\x64\x61taset_revision_id\x18\x03 \x01(\tR\x11\x64\x61tasetRevisionId\x12.\n\x10reference_output\x18\x04 \x01(\tH\x00R\x0freferenceOutput\x88\x01\x01\x12\x1e\n\nevaluators\x18\x05 \x03(\tR\nevaluators\x12\x37\n\x18related_named_prompt_ids\x18\x06 \x03(\tR\x15relatedNamedPromptIds\x12\x34\n\x16related_evaluation_ids\x18\x07 \x03(\tR\x14relatedEvaluationIds\x12\\\n\tmeta_data\x18\x08 \x03(\x0b\x32?.chalk.server.v1.CreatePromptEvaluationRunRequest.MetaDataEntryR\x08metaData\x12P\n\x0fprompt_variants\x18\t \x03(\x0b\x32\'.chalk.server.v1.PromptVariantOperationR\x0epromptVariants\x1aS\n\rMetaDataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12,\n\x05value\x18\x02 \x01(\x0b\x32\x16.google.protobuf.ValueR\x05value:\x02\x38\x01\x42\x13\n\x11_reference_output"p\n!CreatePromptEvaluationRunResponse\x12K\n\x0e\x65valuation_run\x18\x01 \x01(\x0b\x32$.chalk.server.v1.PromptEvaluationRunR\revaluationRun2\xdc\x07\n\rPromptService\x12o\n\x10ListNamedPrompts\x12(.chalk.server.v1.ListNamedPromptsRequest\x1a).chalk.server.v1.ListNamedPromptsResponse"\x06\x90\x02\x01\x80}\x0b\x12i\n\x0eGetNamedPrompt\x12&.chalk.server.v1.GetNamedPromptRequest\x1a\'.chalk.server.v1.GetNamedPromptResponse"\x06\x90\x02\x01\x80}\r\x12o\n\x11\x43reateNamedPrompt\x12).chalk.server.v1.CreateNamedPromptRequest\x1a*.chalk.server.v1.CreateNamedPromptResponse"\x03\x80}\x0c\x12o\n\x11UpdateNamedPrompt\x12).chalk.server.v1.UpdateNamedPromptRequest\x1a*.chalk.server.v1.UpdateNamedPromptResponse"\x03\x80}\x0c\x12u\n\x12ListPromptVariants\x12*.chalk.server.v1.ListPromptVariantsRequest\x1a+.chalk.server.v1.ListPromptVariantsResponse"\x06\x90\x02\x01\x80}\x0b\x12\x87\x01\n\x18ListPromptEvaluationRuns\x12\x30.chalk.server.v1.ListPromptEvaluationRunsRequest\x1a\x31.chalk.server.v1.ListPromptEvaluationRunsResponse"\x06\x90\x02\x01\x80}\x04\x12\x81\x01\n\x16GetPromptEvaluationRun\x12..chalk.server.v1.GetPromptEvaluationRunRequest\x1a/.chalk.server.v1.GetPromptEvaluationRunResponse"\x06\x90\x02\x01\x80}\x04\x12\x87\x01\n\x19\x43reatePromptEvaluationRun\x12\x31.chalk.server.v1.CreatePromptEvaluationRunRequest\x1a\x32.chalk.server.v1.CreatePromptEvaluationRunResponse"\x03\x80}\x04\x42\x94\x01\n\x13\x63om.chalk.server.v1B\x0bPromptProtoP\x01Z\x12server/v1;serverv1\xa2\x02\x03\x43SX\xaa\x02\x0f\x43halk.Server.V1\xca\x02\x0f\x43halk\\Server\\V1\xe2\x02\x1b\x43halk\\Server\\V1\\GPBMetadata\xea\x02\x11\x43halk::Server::V1b\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "chalk.server.v1.prompt_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    _globals["DESCRIPTOR"]._options = None
    _globals[
        "DESCRIPTOR"
    ]._serialized_options = b"\n\023com.chalk.server.v1B\013PromptProtoP\001Z\022server/v1;serverv1\242\002\003CSX\252\002\017Chalk.Server.V1\312\002\017Chalk\\Server\\V1\342\002\033Chalk\\Server\\V1\\GPBMetadata\352\002\021Chalk::Server::V1"
    _globals["_PROVIDERCONFIG_PARAMETERSENTRY"]._options = None
    _globals["_PROVIDERCONFIG_PARAMETERSENTRY"]._serialized_options = b"8\001"
    _globals["_PROMPTEVALUATIONRUN_AGGREGATEMETRICSENTRY"]._options = None
    _globals["_PROMPTEVALUATIONRUN_AGGREGATEMETRICSENTRY"]._serialized_options = b"8\001"
    _globals["_PROMPTEVALUATIONRUN_METADATAENTRY"]._options = None
    _globals["_PROMPTEVALUATIONRUN_METADATAENTRY"]._serialized_options = b"8\001"
    _globals["_CREATEPROMPTEVALUATIONRUNREQUEST_METADATAENTRY"]._options = None
    _globals["_CREATEPROMPTEVALUATIONRUNREQUEST_METADATAENTRY"]._serialized_options = b"8\001"
    _globals["_PROMPTSERVICE"].methods_by_name["ListNamedPrompts"]._options = None
    _globals["_PROMPTSERVICE"].methods_by_name["ListNamedPrompts"]._serialized_options = b"\220\002\001\200}\013"
    _globals["_PROMPTSERVICE"].methods_by_name["GetNamedPrompt"]._options = None
    _globals["_PROMPTSERVICE"].methods_by_name["GetNamedPrompt"]._serialized_options = b"\220\002\001\200}\r"
    _globals["_PROMPTSERVICE"].methods_by_name["CreateNamedPrompt"]._options = None
    _globals["_PROMPTSERVICE"].methods_by_name["CreateNamedPrompt"]._serialized_options = b"\200}\014"
    _globals["_PROMPTSERVICE"].methods_by_name["UpdateNamedPrompt"]._options = None
    _globals["_PROMPTSERVICE"].methods_by_name["UpdateNamedPrompt"]._serialized_options = b"\200}\014"
    _globals["_PROMPTSERVICE"].methods_by_name["ListPromptVariants"]._options = None
    _globals["_PROMPTSERVICE"].methods_by_name["ListPromptVariants"]._serialized_options = b"\220\002\001\200}\013"
    _globals["_PROMPTSERVICE"].methods_by_name["ListPromptEvaluationRuns"]._options = None
    _globals["_PROMPTSERVICE"].methods_by_name[
        "ListPromptEvaluationRuns"
    ]._serialized_options = b"\220\002\001\200}\004"
    _globals["_PROMPTSERVICE"].methods_by_name["GetPromptEvaluationRun"]._options = None
    _globals["_PROMPTSERVICE"].methods_by_name["GetPromptEvaluationRun"]._serialized_options = b"\220\002\001\200}\004"
    _globals["_PROMPTSERVICE"].methods_by_name["CreatePromptEvaluationRun"]._options = None
    _globals["_PROMPTSERVICE"].methods_by_name["CreatePromptEvaluationRun"]._serialized_options = b"\200}\004"
    _globals["_PROMPTTEMPLATE"]._serialized_start = 179
    _globals["_PROMPTTEMPLATE"]._serialized_end = 241
    _globals["_PROVIDERCONFIG"]._serialized_start = 244
    _globals["_PROVIDERCONFIG"]._serialized_end = 559
    _globals["_PROVIDERCONFIG_PARAMETERSENTRY"]._serialized_start = 452
    _globals["_PROVIDERCONFIG_PARAMETERSENTRY"]._serialized_end = 537
    _globals["_PROMPTVARIANT"]._serialized_start = 562
    _globals["_PROMPTVARIANT"]._serialized_end = 1193
    _globals["_NAMEDPROMPT"]._serialized_start = 1196
    _globals["_NAMEDPROMPT"]._serialized_end = 1761
    _globals["_PROMPTEVALUATIONRUN"]._serialized_start = 1764
    _globals["_PROMPTEVALUATIONRUN"]._serialized_end = 2910
    _globals["_PROMPTEVALUATIONRUN_AGGREGATEMETRICSENTRY"]._serialized_start = 2681
    _globals["_PROMPTEVALUATIONRUN_AGGREGATEMETRICSENTRY"]._serialized_end = 2772
    _globals["_PROMPTEVALUATIONRUN_METADATAENTRY"]._serialized_start = 2774
    _globals["_PROMPTEVALUATIONRUN_METADATAENTRY"]._serialized_end = 2857
    _globals["_LISTNAMEDPROMPTSREQUEST"]._serialized_start = 2912
    _globals["_LISTNAMEDPROMPTSREQUEST"]._serialized_end = 3014
    _globals["_LISTNAMEDPROMPTSRESPONSE"]._serialized_start = 3017
    _globals["_LISTNAMEDPROMPTSRESPONSE"]._serialized_end = 3164
    _globals["_GETNAMEDPROMPTREQUEST"]._serialized_start = 3166
    _globals["_GETNAMEDPROMPTREQUEST"]._serialized_end = 3229
    _globals["_GETNAMEDPROMPTRESPONSE"]._serialized_start = 3231
    _globals["_GETNAMEDPROMPTRESPONSE"]._serialized_end = 3342
    _globals["_PROMPTVARIANTOPERATION"]._serialized_start = 3345
    _globals["_PROMPTVARIANTOPERATION"]._serialized_end = 3506
    _globals["_CREATENAMEDPROMPTREQUEST"]._serialized_start = 3509
    _globals["_CREATENAMEDPROMPTREQUEST"]._serialized_end = 3689
    _globals["_CREATENAMEDPROMPTRESPONSE"]._serialized_start = 3691
    _globals["_CREATENAMEDPROMPTRESPONSE"]._serialized_end = 3783
    _globals["_UPDATENAMEDPROMPTOPERATION"]._serialized_start = 3786
    _globals["_UPDATENAMEDPROMPTOPERATION"]._serialized_end = 4109
    _globals["_UPDATENAMEDPROMPTREQUEST"]._serialized_start = 4112
    _globals["_UPDATENAMEDPROMPTREQUEST"]._serialized_end = 4308
    _globals["_UPDATENAMEDPROMPTRESPONSE"]._serialized_start = 4310
    _globals["_UPDATENAMEDPROMPTRESPONSE"]._serialized_end = 4402
    _globals["_LISTPROMPTVARIANTSREQUEST"]._serialized_start = 4405
    _globals["_LISTPROMPTVARIANTSREQUEST"]._serialized_end = 4645
    _globals["_LISTPROMPTVARIANTSRESPONSE"]._serialized_start = 4648
    _globals["_LISTPROMPTVARIANTSRESPONSE"]._serialized_end = 4803
    _globals["_LISTPROMPTEVALUATIONRUNSREQUEST"]._serialized_start = 4806
    _globals["_LISTPROMPTEVALUATIONRUNSREQUEST"]._serialized_end = 4981
    _globals["_LISTPROMPTEVALUATIONRUNSRESPONSE"]._serialized_start = 4984
    _globals["_LISTPROMPTEVALUATIONRUNSRESPONSE"]._serialized_end = 5151
    _globals["_GETPROMPTEVALUATIONRUNREQUEST"]._serialized_start = 5154
    _globals["_GETPROMPTEVALUATIONRUNREQUEST"]._serialized_end = 5501
    _globals["_GETPROMPTEVALUATIONRUNREQUEST_PREFILLOPTIONS"]._serialized_start = 5340
    _globals["_GETPROMPTEVALUATIONRUNREQUEST_PREFILLOPTIONS"]._serialized_end = 5492
    _globals["_GETPROMPTEVALUATIONRUNRESPONSE"]._serialized_start = 5504
    _globals["_GETPROMPTEVALUATIONRUNRESPONSE"]._serialized_end = 5637
    _globals["_CREATEPROMPTEVALUATIONRUNREQUEST"]._serialized_start = 5640
    _globals["_CREATEPROMPTEVALUATIONRUNREQUEST"]._serialized_end = 6259
    _globals["_CREATEPROMPTEVALUATIONRUNREQUEST_METADATAENTRY"]._serialized_start = 2774
    _globals["_CREATEPROMPTEVALUATIONRUNREQUEST_METADATAENTRY"]._serialized_end = 2857
    _globals["_CREATEPROMPTEVALUATIONRUNRESPONSE"]._serialized_start = 6261
    _globals["_CREATEPROMPTEVALUATIONRUNRESPONSE"]._serialized_end = 6373
    _globals["_PROMPTSERVICE"]._serialized_start = 6376
    _globals["_PROMPTSERVICE"]._serialized_end = 7364
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: chalk/server/v1/scheduler.proto
# Protobuf Python Version: 4.25.3
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from chalk._gen.chalk.auth.v1 import permissions_pb2 as chalk_dot_auth_dot_v1_dot_permissions__pb2
from chalk._gen.chalk.server.v1 import scheduled_query_run_pb2 as chalk_dot_server_dot_v1_dot_scheduled__query__run__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1f\x63halk/server/v1/scheduler.proto\x12\x0f\x63halk.server.v1\x1a\x1f\x63halk/auth/v1/permissions.proto\x1a)chalk/server/v1/scheduled_query_run.proto\x1a\x1cgoogle/protobuf/struct.proto"\xad\x04\n"ManualTriggerScheduledQueryRequest\x12"\n\rcron_query_id\x18\x01 \x01(\x03R\x0b\x63ronQueryId\x12p\n\x0fplanner_options\x18\x02 \x03(\x0b\x32G.chalk.server.v1.ManualTriggerScheduledQueryRequest.PlannerOptionsEntryR\x0eplannerOptions\x12\x33\n\x15incremental_resolvers\x18\x03 \x03(\tR\x14incrementalResolvers\x12$\n\x0bmax_samples\x18\x04 \x01(\x03H\x00R\nmaxSamples\x88\x01\x01\x12j\n\renv_overrides\x18\x05 \x03(\x0b\x32\x45.chalk.server.v1.ManualTriggerScheduledQueryRequest.EnvOverridesEntryR\x0c\x65nvOverrides\x1aY\n\x13PlannerOptionsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12,\n\x05value\x18\x02 \x01(\x0b\x32\x16.google.protobuf.ValueR\x05value:\x02\x38\x01\x1a?\n\x11\x45nvOverridesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\x0e\n\x0c_max_samples"y\n#ManualTriggerScheduledQueryResponse\x12R\n\x13scheduled_query_run\x18\x01 \x01(\x0b\x32".chalk.server.v1.ScheduledQueryRunR\x11scheduledQueryRun2\xa2\x01\n\x10SchedulerService\x12\x8d\x01\n\x1bManualTriggerScheduledQuery\x12\x33.chalk.server.v1.ManualTriggerScheduledQueryRequest\x1a\x34.chalk.server.v1.ManualTriggerScheduledQueryResponse"\x03\x80}\x11\x42\x97\x01\n\x13\x63om.chalk.server.v1B\x0eSchedulerProtoP\x01Z\x12server/v1;serverv1\xa2\x02\x03\x43SX\xaa\x02\x0f\x43halk.Server.V1\xca\x02\x0f\x43halk\\Server\\V1\xe2\x02\x1b\x43halk\\Server\\V1\\GPBMetadata\xea\x02\x11\x43halk::Server::V1b\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "chalk.server.v1.scheduler_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    _globals["DESCRIPTOR"]._options = None
    _globals[
        "DESCRIPTOR"
    ]._serialized_options = b"\n\023com.chalk.server.v1B\016SchedulerProtoP\001Z\022server/v1;serverv1\242\002\003CSX\252\002\017Chalk.Server.V1\312\002\017Chalk\\Server\\V1\342\002\033Chalk\\Server\\V1\\GPBMetadata\352\002\021Chalk::Server::V1"
    _globals["_MANUALTRIGGERSCHEDULEDQUERYREQUEST_PLANNEROPTIONSENTRY"]._options = None
    _globals["_MANUALTRIGGERSCHEDULEDQUERYREQUEST_PLANNEROPTIONSENTRY"]._serialized_options = b"8\001"
    _globals["_MANUALTRIGGERSCHEDULEDQUERYREQUEST_ENVOVERRIDESENTRY"]._options = None
    _globals["_MANUALTRIGGERSCHEDULEDQUERYREQUEST_ENVOVERRIDESENTRY"]._serialized_options = b"8\001"
    _globals["_SCHEDULERSERVICE"].methods_by_name["ManualTriggerScheduledQuery"]._options = None
    _globals["_SCHEDULERSERVICE"].methods_by_name["ManualTriggerScheduledQuery"]._serialized_options = b"\200}\021"
    _globals["_MANUALTRIGGERSCHEDULEDQUERYREQUEST"]._serialized_start = 159
    _globals["_MANUALTRIGGERSCHEDULEDQUERYREQUEST"]._serialized_end = 716
    _globals["_MANUALTRIGGERSCHEDULEDQUERYREQUEST_PLANNEROPTIONSENTRY"]._serialized_start = 546
    _globals["_MANUALTRIGGERSCHEDULEDQUERYREQUEST_PLANNEROPTIONSENTRY"]._serialized_end = 635
    _globals["_MANUALTRIGGERSCHEDULEDQUERYREQUEST_ENVOVERRIDESENTRY"]._serialized_start = 637
    _globals["_MANUALTRIGGERSCHEDULEDQUERYREQUEST_ENVOVERRIDESENTRY"]._serialized_end = 700
    _globals["_MANUALTRIGGERSCHEDULEDQUERYRESPONSE"]._serialized_start = 718
    _globals["_MANUALTRIGGERSCHEDULEDQUERYRESPONSE"]._serialized_end = 839
    _globals["_SCHEDULERSERVICE"]._serialized_start = 842
    _globals["_SCHEDULERSERVICE"]._serialized_end = 1004
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

from abc import (
    ABCMeta,
    abstractmethod,
)
from chalk._gen.chalk.engine.v1.plan_server_pb2 import (
    ExecuteQueryRequest,
    ExecuteQueryResponse,
    GetPlanRequest,
    GetPlanResponse,
)
from grpc import (
    Channel,
    Server,
    ServicerContext,
    UnaryUnaryMultiCallable,
)

class PlanServiceStub:
    def __init__(self, channel: Channel) -> None: ...
    GetPlan: UnaryUnaryMultiCallable[
        GetPlanRequest,
        GetPlanResponse,
    ]
    ExecuteQuery: UnaryUnaryMultiCallable[
        ExecuteQueryRequest,
        ExecuteQueryResponse,
    ]
    """Fall-back for executing queries on the python engine"""

class PlanServiceServicer(metaclass=ABCMeta):
    @abstractmethod
    def GetPlan(
        self,
        request: GetPlanRequest,
        context: ServicerContext,
    ) -> GetPlanResponse: ...
    @abstractmethod
    def ExecuteQuery(
        self,
        request: ExecuteQueryRequest,
        context: ServicerContext,
    ) -> ExecuteQueryResponse:
        """Fall-back for executing queries on the python engine"""

def add_PlanServiceServicer_to_server(servicer: PlanServiceServicer, server: Server) -> None: ...



from chalk._gen.chalk.auth.v1 import featurepermission_pb2 as _featurepermission_pb2
from chalk._gen.chalk.auth.v1 import permissions_pb2 as _permissions_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import (
    ClassVar as _ClassVar,
    Iterable as _Iterable,
    Mapping as _Mapping,
    Optional as _Optional,
    Union as _Union,
)

DESCRIPTOR: _descriptor.FileDescriptor

class EnvironmentPermissions(_message.Message):
    __slots__ = ("permissions", "feature_permissions", "customer_claims")
    PERMISSIONS_FIELD_NUMBER: _ClassVar[int]
    FEATURE_PERMISSIONS_FIELD_NUMBER: _ClassVar[int]
    CUSTOMER_CLAIMS_FIELD_NUMBER: _ClassVar[int]
    permissions: _containers.RepeatedScalarFieldContainer[_permissions_pb2.Permission]
    feature_permissions: _featurepermission_pb2.FeaturePermissions
    customer_claims: _containers.RepeatedCompositeFieldContainer[CustomClaim]
    def __init__(
        self,
        permissions: _Optional[_Iterable[_Union[_permissions_pb2.Permission, str]]] = ...,
        feature_permissions: _Optional[_Union[_featurepermission_pb2.FeaturePermissions, _Mapping]] = ...,
        customer_claims: _Optional[_Iterable[_Union[CustomClaim, _Mapping]]] = ...,
    ) -> None: ...

class UserAgent(_message.Message):
    __slots__ = ("client_id", "user_id", "team_id", "permissions_by_environment", "impersonated")
    class PermissionsByEnvironmentEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: EnvironmentPermissions
        def __init__(
            self, key: _Optional[str] = ..., value: _Optional[_Union[EnvironmentPermissions, _Mapping]] = ...
        ) -> None: ...

    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    TEAM_ID_FIELD_NUMBER: _ClassVar[int]
    PERMISSIONS_BY_ENVIRONMENT_FIELD_NUMBER: _ClassVar[int]
    IMPERSONATED_FIELD_NUMBER: _ClassVar[int]
    client_id: str
    user_id: str
    team_id: str
    permissions_by_environment: _containers.MessageMap[str, EnvironmentPermissions]
    impersonated: bool
    def __init__(
        self,
        client_id: _Optional[str] = ...,
        user_id: _Optional[str] = ...,
        team_id: _Optional[str] = ...,
        permissions_by_environment: _Optional[_Mapping[str, EnvironmentPermissions]] = ...,
        impersonated: bool = ...,
    ) -> None: ...

class CustomClaim(_message.Message):
    __slots__ = ("key", "values")
    KEY_FIELD_NUMBER: _ClassVar[int]
    VALUES_FIELD_NUMBER: _ClassVar[int]
    key: str
    values: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, key: _Optional[str] = ..., values: _Optional[_Iterable[str]] = ...) -> None: ...

class ServiceTokenAgent(_message.Message):
    __slots__ = (
        "id",
        "client_id",
        "team_id",
        "environment",
        "permissions",
        "custom_claims",
        "customer_claims",
        "feature_permissions",
    )
    ID_FIELD_NUMBER: _ClassVar[int]
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    TEAM_ID_FIELD_NUMBER: _ClassVar[int]
    ENVIRONMENT_FIELD_NUMBER: _ClassVar[int]
    PERMISSIONS_FIELD_NUMBER: _ClassVar[int]
    CUSTOM_CLAIMS_FIELD_NUMBER: _ClassVar[int]
    CUSTOMER_CLAIMS_FIELD_NUMBER: _ClassVar[int]
    FEATURE_PERMISSIONS_FIELD_NUMBER: _ClassVar[int]
    id: str
    client_id: str
    team_id: str
    environment: str
    permissions: _containers.RepeatedScalarFieldContainer[_permissions_pb2.Permission]
    custom_claims: _containers.RepeatedScalarFieldContainer[str]
    customer_claims: _containers.RepeatedCompositeFieldContainer[CustomClaim]
    feature_permissions: _featurepermission_pb2.FeaturePermissions
    def __init__(
        self,
        id: _Optional[str] = ...,
        client_id: _Optional[str] = ...,
        team_id: _Optional[str] = ...,
        environment: _Optional[str] = ...,
        permissions: _Optional[_Iterable[_Union[_permissions_pb2.Permission, str]]] = ...,
        custom_claims: _Optional[_Iterable[str]] = ...,
        customer_claims: _Optional[_Iterable[_Union[CustomClaim, _Mapping]]] = ...,
        feature_permissions: _Optional[_Union[_featurepermission_pb2.FeaturePermissions, _Mapping]] = ...,
    ) -> None: ...

class EngineAgent(_message.Message):
    __slots__ = ("id", "team_id", "project_id", "environment_id", "impersonated")
    ID_FIELD_NUMBER: _ClassVar[int]
    TEAM_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    ENVIRONMENT_ID_FIELD_NUMBER: _ClassVar[int]
    IMPERSONATED_FIELD_NUMBER: _ClassVar[int]
    id: str
    team_id: str
    project_id: str
    environment_id: str
    impersonated: bool
    def __init__(
        self,
        id: _Optional[str] = ...,
        team_id: _Optional[str] = ...,
        project_id: _Optional[str] = ...,
        environment_id: _Optional[str] = ...,
        impersonated: bool = ...,
    ) -> None: ...

class MetadataServiceAgent(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class TenantAgent(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class Agent(_message.Message):
    __slots__ = ("user_agent", "service_token_agent", "engine_agent", "tenant_agent", "metadata_service_agent")
    USER_AGENT_FIELD_NUMBER: _ClassVar[int]
    SERVICE_TOKEN_AGENT_FIELD_NUMBER: _ClassVar[int]
    ENGINE_AGENT_FIELD_NUMBER: _ClassVar[int]
    TENANT_AGENT_FIELD_NUMBER: _ClassVar[int]
    METADATA_SERVICE_AGENT_FIELD_NUMBER: _ClassVar[int]
    user_agent: UserAgent
    service_token_agent: ServiceTokenAgent
    engine_agent: EngineAgent
    tenant_agent: TenantAgent
    metadata_service_agent: MetadataServiceAgent
    def __init__(
        self,
        user_agent: _Optional[_Union[UserAgent, _Mapping]] = ...,
        service_token_agent: _Optional[_Union[ServiceTokenAgent, _Mapping]] = ...,
        engine_agent: _Optional[_Union[EngineAgent, _Mapping]] = ...,
        tenant_agent: _Optional[_Union[TenantAgent, _Mapping]] = ...,
        metadata_service_agent: _Optional[_Union[MetadataServiceAgent, _Mapping]] = ...,
    ) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""

import grpc

from chalk._gen.chalk.server.v1 import builder_pb2 as chalk_dot_server_dot_v1_dot_builder__pb2


class BuilderServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetSearchConfig = channel.unary_unary(
            "/chalk.server.v1.BuilderService/GetSearchConfig",
            request_serializer=chalk_dot_server_dot_v1_dot_builder__pb2.GetSearchConfigRequest.SerializeToString,
            response_deserializer=chalk_dot_server_dot_v1_dot_builder__pb2.GetSearchConfigResponse.FromString,
        )
        self.ActivateDeployment = channel.unary_unary(
            "/chalk.server.v1.BuilderService/ActivateDeployment",
            request_serializer=chalk_dot_server_dot_v1_dot_builder__pb2.ActivateDeploymentRequest.SerializeToString,
            response_deserializer=chalk_dot_server_dot_v1_dot_builder__pb2.ActivateDeploymentResponse.FromString,
        )
        self.IndexDeployment = channel.unary_unary(
            "/chalk.server.v1.BuilderService/IndexDeployment",
            request_serializer=chalk_dot_server_dot_v1_dot_builder__pb2.IndexDeploymentRequest.SerializeToString,
            response_deserializer=chalk_dot_server_dot_v1_dot_builder__pb2.IndexDeploymentResponse.FromString,
        )
        self.DeployKubeComponents = channel.unary_unary(
            "/chalk.server.v1.BuilderService/DeployKubeComponents",
            request_serializer=chalk_dot_server_dot_v1_dot_builder__pb2.DeployKubeComponentsRequest.SerializeToString,
            response_deserializer=chalk_dot_server_dot_v1_dot_builder__pb2.DeployKubeComponentsResponse.FromString,
        )
        self.RebuildDeployment = channel.unary_unary(
            "/chalk.server.v1.BuilderService/RebuildDeployment",
            request_serializer=chalk_dot_server_dot_v1_dot_builder__pb2.RebuildDeploymentRequest.SerializeToString,
            response_deserializer=chalk_dot_server_dot_v1_dot_builder__pb2.RebuildDeploymentResponse.FromString,
        )
        self.RedeployDeployment = channel.unary_unary(
            "/chalk.server.v1.BuilderService/RedeployDeployment",
            request_serializer=chalk_dot_server_dot_v1_dot_builder__pb2.RedeployDeploymentRequest.SerializeToString,
            response_deserializer=chalk_dot_server_dot_v1_dot_builder__pb2.RedeployDeploymentResponse.FromString,
        )
        self.UploadSource = channel.unary_unary(
            "/chalk.server.v1.BuilderService/UploadSource",
            request_serializer=chalk_dot_server_dot_v1_dot_builder__pb2.UploadSourceRequest.SerializeToString,
            response_deserializer=chalk_dot_server_dot_v1_dot_builder__pb2.UploadSourceResponse.FromString,
        )
        self.LintSource = channel.unary_unary(
            "/chalk.server.v1.BuilderService/LintSource",
            request_serializer=chalk_dot_server_dot_v1_dot_builder__pb2.LintSourceRequest.SerializeToString,
            response_deserializer=chalk_dot_server_dot_v1_dot_builder__pb2.LintSourceResponse.FromString,
        )
        self.GetDeploymentSteps = channel.unary_unary(
            "/chalk.server.v1.BuilderService/GetDeploymentSteps",
            request_serializer=chalk_dot_server_dot_v1_dot_builder__pb2.GetDeploymentStepsRequest.SerializeToString,
            response_deserializer=chalk_dot_server_dot_v1_dot_builder__pb2.GetDeploymentStepsResponse.FromString,
        )
        self.GetDeploymentLogs = channel.unary_unary(
            "/chalk.server.v1.BuilderService/GetDeploymentLogs",
            request_serializer=chalk_dot_server_dot_v1_dot_builder__pb2.GetDeploymentLogsRequest.SerializeToString,
            response_deserializer=chalk_dot_server_dot_v1_dot_builder__pb2.GetDeploymentLogsResponse.FromString,
        )
        self.GetClusterTimescaleDB = channel.unary_unary(
            "/chalk.server.v1.BuilderService/GetClusterTimescaleDB",
            request_serializer=chalk_dot_server_dot_v1_dot_builder__pb2.GetClusterTimescaleDBRequest.SerializeToString,
            response_deserializer=chalk_dot_server_dot_v1_dot_builder__pb2.GetClusterTimescaleDBResponse.FromString,
        )
        self.GetClusterGateway = channel.unary_unary(
            "/chalk.server.v1.BuilderService/GetClusterGateway",
            request_serializer=chalk_dot_server_dot_v1_dot_builder__pb2.GetClusterGatewayRequest.SerializeToString,
            response_deserializer=chalk_dot_server_dot_v1_dot_builder__pb2.GetClusterGatewayResponse.FromString,
        )
        self.GetClusterBackgroundPersistence = channel.unary_unary(
            "/chalk.server.v1.BuilderService/GetClusterBackgroundPersistence",
            request_serializer=chalk_dot_server_dot_v1_dot_builder__pb2.GetClusterBackgroundPersistenceRequest.SerializeToString,
            response_deserializer=chalk_dot_server_dot_v1_dot_builder__pb2.GetClusterBackgroundPersistenceResponse.FromString,
        )
        self.CreateClusterTimescaleDB = channel.unary_unary(
            "/chalk.server.v1.BuilderService/CreateClusterTimescaleDB",
            request_serializer=chalk_dot_server_dot_v1_dot_builder__pb2.CreateClusterTimescaleDBRequest.SerializeToString,
            response_deserializer=chalk_dot_server_dot_v1_dot_builder__pb2.CreateClusterTimescaleDBResponse.FromString,
        )
        self.MigrateClusterTimescaleDB = channel.unary_unary(
            "/chalk.server.v1.BuilderService/MigrateClusterTimescaleDB",
            request_serializer=chalk_dot_server_dot_v1_dot_builder__pb2.MigrateClusterTimescaleDBRequest.SerializeToString,
            response_deserializer=chalk_dot_server_dot_v1_dot_builder__pb2.MigrateClusterTimescaleDBResponse.FromString,
        )
        self.CreateClusterGateway = channel.unary_unary(
            "/chalk.server.v1.BuilderService/CreateClusterGateway",
            request_serializer=chalk_dot_server_dot_v1_dot_builder__pb2.CreateClusterGatewayRequest.SerializeToString,
            response_deserializer=chalk_dot_server_dot_v1_dot_builder__pb2.CreateClusterGatewayResponse.FromString,
        )
        self.CreateClusterBackgroundPersistence = channel.unary_unary(
            "/chalk.server.v1.BuilderService/CreateClusterBackgroundPersistence",
            request_serializer=chalk_dot_server_dot_v1_dot_builder__pb2.CreateClusterBackgroundPersistenceRequest.SerializeToString,
            response_deserializer=chalk_dot_server_dot_v1_dot_builder__pb2.CreateClusterBackgroundPersistenceResponse.FromString,
        )
        self.UpdateEnvironmentVariables = channel.unary_unary(
            "/chalk.server.v1.BuilderService/UpdateEnvironmentVariables",
            request_serializer=chalk_dot_server_dot_v1_dot_builder__pb2.UpdateEnvironmentVariablesRequest.SerializeToString,
            response_deserializer=chalk_dot_server_dot_v1_dot_builder__pb2.UpdateEnvironmentVariablesResponse.FromString,
        )
        self.StartBranch = channel.unary_unary(
            "/chalk.server.v1.BuilderService/StartBranch",
            request_serializer=chalk_dot_server_dot_v1_dot_builder__pb2.StartBranchRequest.SerializeToString,
            response_deserializer=chalk_dot_server_dot_v1_dot_builder__pb2.StartBranchResponse.FromString,
        )
        self.GetNodepools = channel.unary_unary(
            "/chalk.server.v1.BuilderService/GetNodepools",
            request_serializer=chalk_dot_server_dot_v1_dot_builder__pb2.GetNodepoolsRequest.SerializeToString,
            response_deserializer=chalk_dot_server_dot_v1_dot_builder__pb2.GetNodepoolsResponse.FromString,
        )
        self.AddNodepool = channel.unary_unary(
            "/chalk.server.v1.BuilderService/AddNodepool",
            request_serializer=chalk_dot_server_dot_v1_dot_builder__pb2.AddNodepoolRequest.SerializeToString,
            response_deserializer=chalk_dot_server_dot_v1_dot_builder__pb2.AddNodepoolResponse.FromString,
        )
        self.UpdateNodepool = channel.unary_unary(
            "/chalk.server.v1.BuilderService/UpdateNodepool",
            request_serializer=chalk_dot_server_dot_v1_dot_builder__pb2.UpdateNodepoolRequest.SerializeToString,
            response_deserializer=chalk_dot_server_dot_v1_dot_builder__pb2.UpdateNodepoolResponse.FromString,
        )
        self.DeleteNodepool = channel.unary_unary(
            "/chalk.server.v1.BuilderService/DeleteNodepool",
            request_serializer=chalk_dot_server_dot_v1_dot_builder__pb2.DeleteNodepoolRequest.SerializeToString,
            response_deserializer=chalk_dot_server_dot_v1_dot_builder__pb2.DeleteNodepoolResponse.FromString,
        )
        self.GetKarpenterNodepools = channel.unary_unary(
            "/chalk.server.v1.BuilderService/GetKarpenterNodepools",
            request_serializer=chalk_dot_server_dot_v1_dot_builder__pb2.GetKarpenterNodepoolsRequest.SerializeToString,
            response_deserializer=chalk_dot_server_dot_v1_dot_builder__pb2.GetKarpenterNodepoolsResponse.FromString,
        )
        self.AddKarpenterNodepool = channel.unary_unary(
            "/chalk.server.v1.BuilderService/AddKarpenterNodepool",
            request_serializer=chalk_dot_server_dot_v1_dot_builder__pb2.AddKarpenterNodepoolRequest.SerializeToString,
            response_deserializer=chalk_dot_server_dot_v1_dot_builder__pb2.AddKarpenterNodepoolResponse.FromString,
        )
        self.UpdateKarpenterNodepool = channel.unary_unary(
            "/chalk.server.v1.BuilderService/UpdateKarpenterNodepool",
            request_serializer=chalk_dot_server_dot_v1_dot_builder__pb2.UpdateKarpenterNodepoolRequest.SerializeToString,
            response_deserializer=chalk_dot_server_dot_v1_dot_builder__pb2.UpdateKarpenterNodepoolResponse.FromString,
        )
        self.DeleteKarpenterNodepool = channel.unary_unary(
            "/chalk.server.v1.BuilderService/DeleteKarpenterNodepool",
            request_serializer=chalk_dot_server_dot_v1_dot_builder__pb2.DeleteKarpenterNodepoolRequest.SerializeToString,
            response_deserializer=chalk_dot_server_dot_v1_dot_builder__pb2.DeleteKarpenterNodepoolResponse.FromString,
        )
        self.GetKarpenterInstallationMetadata = channel.unary_unary(
            "/chalk.server.v1.BuilderService/GetKarpenterInstallationMetadata",
            request_serializer=chalk_dot_server_dot_v1_dot_builder__pb2.GetKarpenterInstallationMetadataRequest.SerializeToString,
            response_deserializer=chalk_dot_server_dot_v1_dot_builder__pb2.GetKarpenterInstallationMetadataResponse.FromString,
        )
        self.GetTagWeights = channel.unary_unary(
            "/chalk.server.v1.BuilderService/GetTagWeights",
            request_serializer=chalk_dot_server_dot_v1_dot_builder__pb2.GetTagWeightsRequest.SerializeToString,
            response_deserializer=chalk_dot_server_dot_v1_dot_builder__pb2.GetTagWeightsResponse.FromString,
        )
        self.SetTagWeights = channel.unary_unary(
            "/chalk.server.v1.BuilderService/SetTagWeights",
            request_serializer=chalk_dot_server_dot_v1_dot_builder__pb2.SetTagWeightsRequest.SerializeToString,
            response_deserializer=chalk_dot_server_dot_v1_dot_builder__pb2.SetTagWeightsResponse.FromString,
        )


class BuilderServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetSearchConfig(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ActivateDeployment(self, request, context):
        """Takes an existing (past) deployment and promotes the k8s resources / other things associated with it.
        Useful for debugging in local development where the auto activation doesn't work b/c no pubsub.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def IndexDeployment(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeployKubeComponents(self, request, context):
        """Intermediate step in the deployment activation process. Allows for partial migration to the new
        go-api-server builder service.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def RebuildDeployment(self, request, context):
        """Takes an existing (past) deployment and re-creates the image associated with it,
        publishing the image as 'new_image_tag'.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def RedeployDeployment(self, request, context):
        """Triggers a new build with the source code from this deployment and deploys the result"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def UploadSource(self, request, context):
        """Triggers a new build with the provided source code archive and deploys the result"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def LintSource(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetDeploymentSteps(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetDeploymentLogs(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetClusterTimescaleDB(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetClusterGateway(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetClusterBackgroundPersistence(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def CreateClusterTimescaleDB(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def MigrateClusterTimescaleDB(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def CreateClusterGateway(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def CreateClusterBackgroundPersistence(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def UpdateEnvironmentVariables(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def StartBranch(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetNodepools(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def AddNodepool(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def UpdateNodepool(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeleteNodepool(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetKarpenterNodepools(self, request, context):
        """to be deprecated"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def AddKarpenterNodepool(self, request, context):
        """to be deprecated"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def UpdateKarpenterNodepool(self, request, context):
        """to be deprecated"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeleteKarpenterNodepool(self, request, context):
        """to be deprecated"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetKarpenterInstallationMetadata(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetTagWeights(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def SetTagWeights(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_BuilderServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "GetSearchConfig": grpc.unary_unary_rpc_method_handler(
            servicer.GetSearchConfig,
            request_deserializer=chalk_dot_server_dot_v1_dot_builder__pb2.GetSearchConfigRequest.FromString,
            response_serializer=chalk_dot_server_dot_v1_dot_builder__pb2.GetSearchConfigResponse.SerializeToString,
        ),
        "ActivateDeployment": grpc.unary_unary_rpc_method_handler(
            servicer.ActivateDeployment,
            request_deserializer=chalk_dot_server_dot_v1_dot_builder__pb2.ActivateDeploymentRequest.FromString,
            response_serializer=chalk_dot_server_dot_v1_dot_builder__pb2.ActivateDeploymentResponse.SerializeToString,
        ),
        "IndexDeployment": grpc.unary_unary_rpc_method_handler(
            servicer.IndexDeployment,
            request_deserializer=chalk_dot_server_dot_v1_dot_builder__pb2.IndexDeploymentRequest.FromString,
            response_serializer=chalk_dot_server_dot_v1_dot_builder__pb2.IndexDeploymentResponse.SerializeToString,
        ),
        "DeployKubeComponents": grpc.unary_unary_rpc_method_handler(
            servicer.DeployKubeComponents,
            request_deserializer=chalk_dot_server_dot_v1_dot_builder__pb2.DeployKubeComponentsRequest.FromString,
            response_serializer=chalk_dot_server_dot_v1_dot_builder__pb2.DeployKubeComponentsResponse.SerializeToString,
        ),
        "RebuildDeployment": grpc.unary_unary_rpc_method_handler(
            servicer.RebuildDeployment,
            request_deserializer=chalk_dot_server_dot_v1_dot_builder__pb2.RebuildDeploymentRequest.FromString,
            response_serializer=chalk_dot_server_dot_v1_dot_builder__pb2.RebuildDeploymentResponse.SerializeToString,
        ),
        "RedeployDeployment": grpc.unary_unary_rpc_method_handler(
            servicer.RedeployDeployment,
            request_deserializer=chalk_dot_server_dot_v1_dot_builder__pb2.RedeployDeploymentRequest.FromString,
            response_serializer=chalk_dot_server_dot_v1_dot_builder__pb2.RedeployDeploymentResponse.SerializeToString,
        ),
        "UploadSource": grpc.unary_unary_rpc_method_handler(
            servicer.UploadSource,
            request_deserializer=chalk_dot_server_dot_v1_dot_builder__pb2.UploadSourceRequest.FromString,
            response_serializer=chalk_dot_server_dot_v1_dot_builder__pb2.UploadSourceResponse.SerializeToString,
        ),
        "LintSource": grpc.unary_unary_rpc_method_handler(
            servicer.LintSource,
            request_deserializer=chalk_dot_server_dot_v1_dot_builder__pb2.LintSourceRequest.FromString,
            response_serializer=chalk_dot_server_dot_v1_dot_builder__pb2.LintSourceResponse.SerializeToString,
        ),
        "GetDeploymentSteps": grpc.unary_unary_rpc_method_handler(
            servicer.GetDeploymentSteps,
            request_deserializer=chalk_dot_server_dot_v1_dot_builder__pb2.GetDeploymentStepsRequest.FromString,
            response_serializer=chalk_dot_server_dot_v1_dot_builder__pb2.GetDeploymentStepsResponse.SerializeToString,
        ),
        "GetDeploymentLogs": grpc.unary_unary_rpc_method_handler(
            servicer.GetDeploymentLogs,
            request_deserializer=chalk_dot_server_dot_v1_dot_builder__pb2.GetDeploymentLogsRequest.FromString,
            response_serializer=chalk_dot_server_dot_v1_dot_builder__pb2.GetDeploymentLogsResponse.SerializeToString,
        ),
        "GetClusterTimescaleDB": grpc.unary_unary_rpc_method_handler(
            servicer.GetClusterTimescaleDB,
            request_deserializer=chalk_dot_server_dot_v1_dot_builder__pb2.GetClusterTimescaleDBRequest.FromString,
            response_serializer=chalk_dot_server_dot_v1_dot_builder__pb2.GetClusterTimescaleDBResponse.SerializeToString,
        ),
        "GetClusterGateway": grpc.unary_unary_rpc_method_handler(
            servicer.GetClusterGateway,
            request_deserializer=chalk_dot_server_dot_v1_dot_builder__pb2.GetClusterGatewayRequest.FromString,
            response_serializer=chalk_dot_server_dot_v1_dot_builder__pb2.GetClusterGatewayResponse.SerializeToString,
        ),
        "GetClusterBackgroundPersistence": grpc.unary_unary_rpc_method_handler(
            servicer.GetClusterBackgroundPersistence,
            request_deserializer=chalk_dot_server_dot_v1_dot_builder__pb2.GetClusterBackgroundPersistenceRequest.FromString,
            response_serializer=chalk_dot_server_dot_v1_dot_builder__pb2.GetClusterBackgroundPersistenceResponse.SerializeToString,
        ),
        "CreateClusterTimescaleDB": grpc.unary_unary_rpc_method_handler(
            servicer.CreateClusterTimescaleDB,
            request_deserializer=chalk_dot_server_dot_v1_dot_builder__pb2.CreateClusterTimescaleDBRequest.FromString,
            response_serializer=chalk_dot_server_dot_v1_dot_builder__pb2.CreateClusterTimescaleDBResponse.SerializeToString,
        ),
        "MigrateClusterTimescaleDB": grpc.unary_unary_rpc_method_handler(
            servicer.MigrateClusterTimescaleDB,
            request_deserializer=chalk_dot_server_dot_v1_dot_builder__pb2.MigrateClusterTimescaleDBRequest.FromString,
            response_serializer=chalk_dot_server_dot_v1_dot_builder__pb2.MigrateClusterTimescaleDBResponse.SerializeToString,
        ),
        "CreateClusterGateway": grpc.unary_unary_rpc_method_handler(
            servicer.CreateClusterGateway,
            request_deserializer=chalk_dot_server_dot_v1_dot_builder__pb2.CreateClusterGatewayRequest.FromString,
            response_serializer=chalk_dot_server_dot_v1_dot_builder__pb2.CreateClusterGatewayResponse.SerializeToString,
        ),
        "CreateClusterBackgroundPersistence": grpc.unary_unary_rpc_method_handler(
            servicer.CreateClusterBackgroundPersistence,
            request_deserializer=chalk_dot_server_dot_v1_dot_builder__pb2.CreateClusterBackgroundPersistenceRequest.FromString,
            response_serializer=chalk_dot_server_dot_v1_dot_builder__pb2.CreateClusterBackgroundPersistenceResponse.SerializeToString,
        ),
        "UpdateEnvironmentVariables": grpc.unary_unary_rpc_method_handler(
            servicer.UpdateEnvironmentVariables,
            request_deserializer=chalk_dot_server_dot_v1_dot_builder__pb2.UpdateEnvironmentVariablesRequest.FromString,
            response_serializer=chalk_dot_server_dot_v1_dot_builder__pb2.UpdateEnvironmentVariablesResponse.SerializeToString,
        ),
        "StartBranch": grpc.unary_unary_rpc_method_handler(
            servicer.StartBranch,
            request_deserializer=chalk_dot_server_dot_v1_dot_builder__pb2.StartBranchRequest.FromString,
            response_serializer=chalk_dot_server_dot_v1_dot_builder__pb2.StartBranchResponse.SerializeToString,
        ),
        "GetNodepools": grpc.unary_unary_rpc_method_handler(
            servicer.GetNodepools,
            request_deserializer=chalk_dot_server_dot_v1_dot_builder__pb2.GetNodepoolsRequest.FromString,
            response_serializer=chalk_dot_server_dot_v1_dot_builder__pb2.GetNodepoolsResponse.SerializeToString,
        ),
        "AddNodepool": grpc.unary_unary_rpc_method_handler(
            servicer.AddNodepool,
            request_deserializer=chalk_dot_server_dot_v1_dot_builder__pb2.AddNodepoolRequest.FromString,
            response_serializer=chalk_dot_server_dot_v1_dot_builder__pb2.AddNodepoolResponse.SerializeToString,
        ),
        "UpdateNodepool": grpc.unary_unary_rpc_method_handler(
            servicer.UpdateNodepool,
            request_deserializer=chalk_dot_server_dot_v1_dot_builder__pb2.UpdateNodepoolRequest.FromString,
            response_serializer=chalk_dot_server_dot_v1_dot_builder__pb2.UpdateNodepoolResponse.SerializeToString,
        ),
        "DeleteNodepool": grpc.unary_unary_rpc_method_handler(
            servicer.DeleteNodepool,
            request_deserializer=chalk_dot_server_dot_v1_dot_builder__pb2.DeleteNodepoolRequest.FromString,
            response_serializer=chalk_dot_server_dot_v1_dot_builder__pb2.DeleteNodepoolResponse.SerializeToString,
        ),
        "GetKarpenterNodepools": grpc.unary_unary_rpc_method_handler(
            servicer.GetKarpenterNodepools,
            request_deserializer=chalk_dot_server_dot_v1_dot_builder__pb2.GetKarpenterNodepoolsRequest.FromString,
            response_serializer=chalk_dot_server_dot_v1_dot_builder__pb2.GetKarpenterNodepoolsResponse.SerializeToString,
        ),
        "AddKarpenterNodepool": grpc.unary_unary_rpc_method_handler(
            servicer.AddKarpenterNodepool,
            request_deserializer=chalk_dot_server_dot_v1_dot_builder__pb2.AddKarpenterNodepoolRequest.FromString,
            response_serializer=chalk_dot_server_dot_v1_dot_builder__pb2.AddKarpenterNodepoolResponse.SerializeToString,
        ),
        "UpdateKarpenterNodepool": grpc.unary_unary_rpc_method_handler(
            servicer.UpdateKarpenterNodepool,
            request_deserializer=chalk_dot_server_dot_v1_dot_builder__pb2.UpdateKarpenterNodepoolRequest.FromString,
            response_serializer=chalk_dot_server_dot_v1_dot_builder__pb2.UpdateKarpenterNodepoolResponse.SerializeToString,
        ),
        "DeleteKarpenterNodepool": grpc.unary_unary_rpc_method_handler(
            servicer.DeleteKarpenterNodepool,
            request_deserializer=chalk_dot_server_dot_v1_dot_builder__pb2.DeleteKarpenterNodepoolRequest.FromString,
            response_serializer=chalk_dot_server_dot_v1_dot_builder__pb2.DeleteKarpenterNodepoolResponse.SerializeToString,
        ),
        "GetKarpenterInstallationMetadata": grpc.unary_unary_rpc_method_handler(
            servicer.GetKarpenterInstallationMetadata,
            request_deserializer=chalk_dot_server_dot_v1_dot_builder__pb2.GetKarpenterInstallationMetadataRequest.FromString,
            response_serializer=chalk_dot_server_dot_v1_dot_builder__pb2.GetKarpenterInstallationMetadataResponse.SerializeToString,
        ),
        "GetTagWeights": grpc.unary_unary_rpc_method_handler(
            servicer.GetTagWeights,
            request_deserializer=chalk_dot_server_dot_v1_dot_builder__pb2.GetTagWeightsRequest.FromString,
            response_serializer=chalk_dot_server_dot_v1_dot_builder__pb2.GetTagWeightsResponse.SerializeToString,
        ),
        "SetTagWeights": grpc.unary_unary_rpc_method_handler(
            servicer.SetTagWeights,
            request_deserializer=chalk_dot_server_dot_v1_dot_builder__pb2.SetTagWeightsRequest.FromString,
            response_serializer=chalk_dot_server_dot_v1_dot_builder__pb2.SetTagWeightsResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler("chalk.server.v1.BuilderService", rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class BuilderService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetSearchConfig(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/chalk.server.v1.BuilderService/GetSearchConfig",
            chalk_dot_server_dot_v1_dot_builder__pb2.GetSearchConfigRequest.SerializeToString,
            chalk_dot_server_dot_v1_dot_builder__pb2.GetSearchConfigResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ActivateDeployment(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/chalk.server.v1.BuilderService/ActivateDeployment",
            chalk_dot_server_dot_v1_dot_builder__pb2.ActivateDeploymentRequest.SerializeToString,
            chalk_dot_server_dot_v1_dot_builder__pb2.ActivateDeploymentResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def IndexDeployment(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/chalk.server.v1.BuilderService/IndexDeployment",
            chalk_dot_server_dot_v1_dot_builder__pb2.IndexDeploymentRequest.SerializeToString,
            chalk_dot_server_dot_v1_dot_builder__pb2.IndexDeploymentResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeployKubeComponents(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/chalk.server.v1.BuilderService/DeployKubeComponents",
            chalk_dot_server_dot_v1_dot_builder__pb2.DeployKubeComponentsRequest.SerializeToString,
            chalk_dot_server_dot_v1_dot_builder__pb2.DeployKubeComponentsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def RebuildDeployment(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/chalk.server.v1.BuilderService/RebuildDeployment",
            chalk_dot_server_dot_v1_dot_builder__pb2.RebuildDeploymentRequest.SerializeToString,
            chalk_dot_server_dot_v1_dot_builder__pb2.RebuildDeploymentResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def RedeployDeployment(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/chalk.server.v1.BuilderService/RedeployDeployment",
            chalk_dot_server_dot_v1_dot_builder__pb2.RedeployDeploymentRequest.SerializeToString,
            chalk_dot_server_dot_v1_dot_builder__pb2.RedeployDeploymentResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def UploadSource(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/chalk.server.v1.BuilderService/UploadSource",
            chalk_dot_server_dot_v1_dot_builder__pb2.UploadSourceRequest.SerializeToString,
            chalk_dot_server_dot_v1_dot_builder__pb2.UploadSourceResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def LintSource(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/chalk.server.v1.BuilderService/LintSource",
            chalk_dot_server_dot_v1_dot_builder__pb2.LintSourceRequest.SerializeToString,
            chalk_dot_server_dot_v1_dot_builder__pb2.LintSourceResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetDeploymentSteps(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/chalk.server.v1.BuilderService/GetDeploymentSteps",
            chalk_dot_server_dot_v1_dot_builder__pb2.GetDeploymentStepsRequest.SerializeToString,
            chalk_dot_server_dot_v1_dot_builder__pb2.GetDeploymentStepsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetDeploymentLogs(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/chalk.server.v1.BuilderService/GetDeploymentLogs",
            chalk_dot_server_dot_v1_dot_builder__pb2.GetDeploymentLogsRequest.SerializeToString,
            chalk_dot_server_dot_v1_dot_builder__pb2.GetDeploymentLogsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetClusterTimescaleDB(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/chalk.server.v1.BuilderService/GetClusterTimescaleDB",
            chalk_dot_server_dot_v1_dot_builder__pb2.GetClusterTimescaleDBRequest.SerializeToString,
            chalk_dot_server_dot_v1_dot_builder__pb2.GetClusterTimescaleDBResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetClusterGateway(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/chalk.server.v1.BuilderService/GetClusterGateway",
            chalk_dot_server_dot_v1_dot_builder__pb2.GetClusterGatewayRequest.SerializeToString,
            chalk_dot_server_dot_v1_dot_builder__pb2.GetClusterGatewayResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetClusterBackgroundPersistence(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/chalk.server.v1.BuilderService/GetClusterBackgroundPersistence",
            chalk_dot_server_dot_v1_dot_builder__pb2.GetClusterBackgroundPersistenceRequest.SerializeToString,
            chalk_dot_server_dot_v1_dot_builder__pb2.GetClusterBackgroundPersistenceResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def CreateClusterTimescaleDB(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/chalk.server.v1.BuilderService/CreateClusterTimescaleDB",
            chalk_dot_server_dot_v1_dot_builder__pb2.CreateClusterTimescaleDBRequest.SerializeToString,
            chalk_dot_server_dot_v1_dot_builder__pb2.CreateClusterTimescaleDBResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def MigrateClusterTimescaleDB(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/chalk.server.v1.BuilderService/MigrateClusterTimescaleDB",
            chalk_dot_server_dot_v1_dot_builder__pb2.MigrateClusterTimescaleDBRequest.SerializeToString,
            chalk_dot_server_dot_v1_dot_builder__pb2.MigrateClusterTimescaleDBResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def CreateClusterGateway(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/chalk.server.v1.BuilderService/CreateClusterGateway",
            chalk_dot_server_dot_v1_dot_builder__pb2.CreateClusterGatewayRequest.SerializeToString,
            chalk_dot_server_dot_v1_dot_builder__pb2.CreateClusterGatewayResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def CreateClusterBackgroundPersistence(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/chalk.server.v1.BuilderService/CreateClusterBackgroundPersistence",
            chalk_dot_server_dot_v1_dot_builder__pb2.CreateClusterBackgroundPersistenceRequest.SerializeToString,
            chalk_dot_server_dot_v1_dot_builder__pb2.CreateClusterBackgroundPersistenceResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def UpdateEnvironmentVariables(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/chalk.server.v1.BuilderService/UpdateEnvironmentVariables",
            chalk_dot_server_dot_v1_dot_builder__pb2.UpdateEnvironmentVariablesRequest.SerializeToString,
            chalk_dot_server_dot_v1_dot_builder__pb2.UpdateEnvironmentVariablesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def StartBranch(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/chalk.server.v1.BuilderService/StartBranch",
            chalk_dot_server_dot_v1_dot_builder__pb2.StartBranchRequest.SerializeToString,
            chalk_dot_server_dot_v1_dot_builder__pb2.StartBranchResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetNodepools(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/chalk.server.v1.BuilderService/GetNodepools",
            chalk_dot_server_dot_v1_dot_builder__pb2.GetNodepoolsRequest.SerializeToString,
            chalk_dot_server_dot_v1_dot_builder__pb2.GetNodepoolsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def AddNodepool(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/chalk.server.v1.BuilderService/AddNodepool",
            chalk_dot_server_dot_v1_dot_builder__pb2.AddNodepoolRequest.SerializeToString,
            chalk_dot_server_dot_v1_dot_builder__pb2.AddNodepoolResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def UpdateNodepool(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/chalk.server.v1.BuilderService/UpdateNodepool",
            chalk_dot_server_dot_v1_dot_builder__pb2.UpdateNodepoolRequest.SerializeToString,
            chalk_dot_server_dot_v1_dot_builder__pb2.UpdateNodepoolResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeleteNodepool(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/chalk.server.v1.BuilderService/DeleteNodepool",
            chalk_dot_server_dot_v1_dot_builder__pb2.DeleteNodepoolRequest.SerializeToString,
            chalk_dot_server_dot_v1_dot_builder__pb2.DeleteNodepoolResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetKarpenterNodepools(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/chalk.server.v1.BuilderService/GetKarpenterNodepools",
            chalk_dot_server_dot_v1_dot_builder__pb2.GetKarpenterNodepoolsRequest.SerializeToString,
            chalk_dot_server_dot_v1_dot_builder__pb2.GetKarpenterNodepoolsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def AddKarpenterNodepool(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/chalk.server.v1.BuilderService/AddKarpenterNodepool",
            chalk_dot_server_dot_v1_dot_builder__pb2.AddKarpenterNodepoolRequest.SerializeToString,
            chalk_dot_server_dot_v1_dot_builder__pb2.AddKarpenterNodepoolResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def UpdateKarpenterNodepool(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/chalk.server.v1.BuilderService/UpdateKarpenterNodepool",
            chalk_dot_server_dot_v1_dot_builder__pb2.UpdateKarpenterNodepoolRequest.SerializeToString,
            chalk_dot_server_dot_v1_dot_builder__pb2.UpdateKarpenterNodepoolResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeleteKarpenterNodepool(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/chalk.server.v1.BuilderService/DeleteKarpenterNodepool",
            chalk_dot_server_dot_v1_dot_builder__pb2.DeleteKarpenterNodepoolRequest.SerializeToString,
            chalk_dot_server_dot_v1_dot_builder__pb2.DeleteKarpenterNodepoolResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetKarpenterInstallationMetadata(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/chalk.server.v1.BuilderService/GetKarpenterInstallationMetadata",
            chalk_dot_server_dot_v1_dot_builder__pb2.GetKarpenterInstallationMetadataRequest.SerializeToString,
            chalk_dot_server_dot_v1_dot_builder__pb2.GetKarpenterInstallationMetadataResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetTagWeights(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/chalk.server.v1.BuilderService/GetTagWeights",
            chalk_dot_server_dot_v1_dot_builder__pb2.GetTagWeightsRequest.SerializeToString,
            chalk_dot_server_dot_v1_dot_builder__pb2.GetTagWeightsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def SetTagWeights(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/chalk.server.v1.BuilderService/SetTagWeights",
            chalk_dot_server_dot_v1_dot_builder__pb2.SetTagWeightsRequest.SerializeToString,
            chalk_dot_server_dot_v1_dot_builder__pb2.SetTagWeightsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )


class ClusterBuilderServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateKafkaTopics = channel.unary_unary(
            "/chalk.server.v1.ClusterBuilderService/CreateKafkaTopics",
            request_serializer=chalk_dot_server_dot_v1_dot_builder__pb2.CreateKafkaTopicsRequest.SerializeToString,
            response_deserializer=chalk_dot_server_dot_v1_dot_builder__pb2.CreateKafkaTopicsResponse.FromString,
        )
        self.GetKafkaTopics = channel.unary_unary(
            "/chalk.server.v1.ClusterBuilderService/GetKafkaTopics",
            request_serializer=chalk_dot_server_dot_v1_dot_builder__pb2.GetKafkaTopicsRequest.SerializeToString,
            response_deserializer=chalk_dot_server_dot_v1_dot_builder__pb2.GetKafkaTopicsResponse.FromString,
        )


class ClusterBuilderServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateKafkaTopics(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetKafkaTopics(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_ClusterBuilderServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "CreateKafkaTopics": grpc.unary_unary_rpc_method_handler(
            servicer.CreateKafkaTopics,
            request_deserializer=chalk_dot_server_dot_v1_dot_builder__pb2.CreateKafkaTopicsRequest.FromString,
            response_serializer=chalk_dot_server_dot_v1_dot_builder__pb2.CreateKafkaTopicsResponse.SerializeToString,
        ),
        "GetKafkaTopics": grpc.unary_unary_rpc_method_handler(
            servicer.GetKafkaTopics,
            request_deserializer=chalk_dot_server_dot_v1_dot_builder__pb2.GetKafkaTopicsRequest.FromString,
            response_serializer=chalk_dot_server_dot_v1_dot_builder__pb2.GetKafkaTopicsResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler("chalk.server.v1.ClusterBuilderService", rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class ClusterBuilderService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateKafkaTopics(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/chalk.server.v1.ClusterBuilderService/CreateKafkaTopics",
            chalk_dot_server_dot_v1_dot_builder__pb2.CreateKafkaTopicsRequest.SerializeToString,
            chalk_dot_server_dot_v1_dot_builder__pb2.CreateKafkaTopicsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetKafkaTopics(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/chalk.server.v1.ClusterBuilderService/GetKafkaTopics",
            chalk_dot_server_dot_v1_dot_builder__pb2.GetKafkaTopicsRequest.SerializeToString,
            chalk_dot_server_dot_v1_dot_builder__pb2.GetKafkaTopicsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""

import grpc

from chalk._gen.chalk.server.v1 import graph_pb2 as chalk_dot_server_dot_v1_dot_graph__pb2


class GraphServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetFeatureSQL = channel.unary_unary(
            "/chalk.server.v1.GraphService/GetFeatureSQL",
            request_serializer=chalk_dot_server_dot_v1_dot_graph__pb2.GetFeatureSQLRequest.SerializeToString,
            response_deserializer=chalk_dot_server_dot_v1_dot_graph__pb2.GetFeatureSQLResponse.FromString,
        )
        self.GetFeaturesMetadata = channel.unary_unary(
            "/chalk.server.v1.GraphService/GetFeaturesMetadata",
            request_serializer=chalk_dot_server_dot_v1_dot_graph__pb2.GetFeaturesMetadataRequest.SerializeToString,
            response_deserializer=chalk_dot_server_dot_v1_dot_graph__pb2.GetFeaturesMetadataResponse.FromString,
        )
        self.GetGraph = channel.unary_unary(
            "/chalk.server.v1.GraphService/GetGraph",
            request_serializer=chalk_dot_server_dot_v1_dot_graph__pb2.GetGraphRequest.SerializeToString,
            response_deserializer=chalk_dot_server_dot_v1_dot_graph__pb2.GetGraphResponse.FromString,
        )
        self.UpdateGraph = channel.unary_unary(
            "/chalk.server.v1.GraphService/UpdateGraph",
            request_serializer=chalk_dot_server_dot_v1_dot_graph__pb2.UpdateGraphRequest.SerializeToString,
            response_deserializer=chalk_dot_server_dot_v1_dot_graph__pb2.UpdateGraphResponse.FromString,
        )
        self.GetCodegenFeaturesFromGraph = channel.unary_unary(
            "/chalk.server.v1.GraphService/GetCodegenFeaturesFromGraph",
            request_serializer=chalk_dot_server_dot_v1_dot_graph__pb2.GetCodegenFeaturesFromGraphRequest.SerializeToString,
            response_deserializer=chalk_dot_server_dot_v1_dot_graph__pb2.GetCodegenFeaturesFromGraphResponse.FromString,
        )


class GraphServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetFeatureSQL(self, request, context):
        """GetFeatureSQL returns the feature SQLs for a given deployment."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetFeaturesMetadata(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetGraph(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def UpdateGraph(self, request, context):
        """UpdateGraph uploads the protobuf graph for a given deployment."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetCodegenFeaturesFromGraph(self, request, context):
        """GetCodegenFeaturesFromGraph returns Chalk features generated from the protograph"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_GraphServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "GetFeatureSQL": grpc.unary_unary_rpc_method_handler(
            servicer.GetFeatureSQL,
            request_deserializer=chalk_dot_server_dot_v1_dot_graph__pb2.GetFeatureSQLRequest.FromString,
            response_serializer=chalk_dot_server_dot_v1_dot_graph__pb2.GetFeatureSQLResponse.SerializeToString,
        ),
        "GetFeaturesMetadata": grpc.unary_unary_rpc_method_handler(
            servicer.GetFeaturesMetadata,
            request_deserializer=chalk_dot_server_dot_v1_dot_graph__pb2.GetFeaturesMetadataRequest.FromString,
            response_serializer=chalk_dot_server_dot_v1_dot_graph__pb2.GetFeaturesMetadataResponse.SerializeToString,
        ),
        "GetGraph": grpc.unary_unary_rpc_method_handler(
            servicer.GetGraph,
            request_deserializer=chalk_dot_server_dot_v1_dot_graph__pb2.GetGraphRequest.FromString,
            response_serializer=chalk_dot_server_dot_v1_dot_graph__pb2.GetGraphResponse.SerializeToString,
        ),
        "UpdateGraph": grpc.unary_unary_rpc_method_handler(
            servicer.UpdateGraph,
            request_deserializer=chalk_dot_server_dot_v1_dot_graph__pb2.UpdateGraphRequest.FromString,
            response_serializer=chalk_dot_server_dot_v1_dot_graph__pb2.UpdateGraphResponse.SerializeToString,
        ),
        "GetCodegenFeaturesFromGraph": grpc.unary_unary_rpc_method_handler(
            servicer.GetCodegenFeaturesFromGraph,
            request_deserializer=chalk_dot_server_dot_v1_dot_graph__pb2.GetCodegenFeaturesFromGraphRequest.FromString,
            response_serializer=chalk_dot_server_dot_v1_dot_graph__pb2.GetCodegenFeaturesFromGraphResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler("chalk.server.v1.GraphService", rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class GraphService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetFeatureSQL(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/chalk.server.v1.GraphService/GetFeatureSQL",
            chalk_dot_server_dot_v1_dot_graph__pb2.GetFeatureSQLRequest.SerializeToString,
            chalk_dot_server_dot_v1_dot_graph__pb2.GetFeatureSQLResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetFeaturesMetadata(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/chalk.server.v1.GraphService/GetFeaturesMetadata",
            chalk_dot_server_dot_v1_dot_graph__pb2.GetFeaturesMetadataRequest.SerializeToString,
            chalk_dot_server_dot_v1_dot_graph__pb2.GetFeaturesMetadataResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetGraph(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/chalk.server.v1.GraphService/GetGraph",
            chalk_dot_server_dot_v1_dot_graph__pb2.GetGraphRequest.SerializeToString,
            chalk_dot_server_dot_v1_dot_graph__pb2.GetGraphResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def UpdateGraph(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/chalk.server.v1.GraphService/UpdateGraph",
            chalk_dot_server_dot_v1_dot_graph__pb2.UpdateGraphRequest.SerializeToString,
            chalk_dot_server_dot_v1_dot_graph__pb2.UpdateGraphResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetCodegenFeaturesFromGraph(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/chalk.server.v1.GraphService/GetCodegenFeaturesFromGraph",
            chalk_dot_server_dot_v1_dot_graph__pb2.GetCodegenFeaturesFromGraphRequest.SerializeToString,
            chalk_dot_server_dot_v1_dot_graph__pb2.GetCodegenFeaturesFromGraphResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



from chalk._gen.chalk.server.v1 import offline_queries_pb2 as _offline_queries_pb2
from google.protobuf import field_mask_pb2 as _field_mask_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ScheduledQueryRun(_message.Message):
    __slots__ = (
        "id",
        "environment_id",
        "deployment_id",
        "run_id",
        "cron_query_id",
        "cron_query_schedule_id",
        "cron_name",
        "gcr_execution_id",
        "gcr_job_name",
        "offline_query_id",
        "created_at",
        "updated_at",
    )
    ID_FIELD_NUMBER: _ClassVar[int]
    ENVIRONMENT_ID_FIELD_NUMBER: _ClassVar[int]
    DEPLOYMENT_ID_FIELD_NUMBER: _ClassVar[int]
    RUN_ID_FIELD_NUMBER: _ClassVar[int]
    CRON_QUERY_ID_FIELD_NUMBER: _ClassVar[int]
    CRON_QUERY_SCHEDULE_ID_FIELD_NUMBER: _ClassVar[int]
    CRON_NAME_FIELD_NUMBER: _ClassVar[int]
    GCR_EXECUTION_ID_FIELD_NUMBER: _ClassVar[int]
    GCR_JOB_NAME_FIELD_NUMBER: _ClassVar[int]
    OFFLINE_QUERY_ID_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    id: int
    environment_id: str
    deployment_id: str
    run_id: str
    cron_query_id: int
    cron_query_schedule_id: int
    cron_name: str
    gcr_execution_id: str
    gcr_job_name: str
    offline_query_id: str
    created_at: _timestamp_pb2.Timestamp
    updated_at: _timestamp_pb2.Timestamp
    def __init__(
        self,
        id: _Optional[int] = ...,
        environment_id: _Optional[str] = ...,
        deployment_id: _Optional[str] = ...,
        run_id: _Optional[str] = ...,
        cron_query_id: _Optional[int] = ...,
        cron_query_schedule_id: _Optional[int] = ...,
        cron_name: _Optional[str] = ...,
        gcr_execution_id: _Optional[str] = ...,
        gcr_job_name: _Optional[str] = ...,
        offline_query_id: _Optional[str] = ...,
        created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...,
        updated_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...,
    ) -> None: ...

class GetScheduledQueryRunRequest(_message.Message):
    __slots__ = ("run_id", "offline_query_id", "get_mask")
    RUN_ID_FIELD_NUMBER: _ClassVar[int]
    OFFLINE_QUERY_ID_FIELD_NUMBER: _ClassVar[int]
    GET_MASK_FIELD_NUMBER: _ClassVar[int]
    run_id: int
    offline_query_id: str
    get_mask: _field_mask_pb2.FieldMask
    def __init__(
        self,
        run_id: _Optional[int] = ...,
        offline_query_id: _Optional[str] = ...,
        get_mask: _Optional[_Union[_field_mask_pb2.FieldMask, _Mapping]] = ...,
    ) -> None: ...

class GetScheduledQueryRunResponse(_message.Message):
    __slots__ = ("scheduled_query_run", "offline_query")
    SCHEDULED_QUERY_RUN_FIELD_NUMBER: _ClassVar[int]
    OFFLINE_QUERY_FIELD_NUMBER: _ClassVar[int]
    scheduled_query_run: ScheduledQueryRun
    offline_query: _offline_queries_pb2.OfflineQueryMeta
    def __init__(
        self,
        scheduled_query_run: _Optional[_Union[ScheduledQueryRun, _Mapping]] = ...,
        offline_query: _Optional[_Union[_offline_queries_pb2.OfflineQueryMeta, _Mapping]] = ...,
    ) -> None: ...
